module Pot
  class Bundle

    class UndefinedPackage < ::StandardError
      def message
        "Package definition not found for key: #{@message}"
      end
    end

    def initialize(packages = [])
      @packages = [packages].flatten
    end

    def list
      all = []

      @packages.each do |package_name|
        cloud_info "Requires package #{package_name}\n"

        package = Pot::Package::REGISTER[package_name]
        raise UndefinedPackage, package_name unless package
        package = select_package(package_name, package) if package.is_a? Array # handle virtual package selection

        tree = package.tree do |parent, child, depth|
          indent = "\t" * depth; cloud_info "#{indent}Package #{parent.name} requires #{child.name}"
        end

        all << tree
      end

      normalize(all)
    end

    def add(package)
      @packages << package
    end

    private

      def cloud_info(message)
        Pot.logger.info(message) if Pot.config.cloud or Pot.logger.debug?
      end

      def select_package(name, packages)
        if packages.size <= 1
          package = packages.first
        else
          package = choose do |menu|
            menu.prompt = "Multiple choices exist for virtual package #{name}"
            menu.choices *packages.collect(&:to_s)
          end
          package = Pot::Package::REGISTER[package]
        end

        cloud_info "Selecting #{package.to_s} for virtual package #{name}"

        package
      end

      def normalize(all, &block)
        all = all.flatten.uniq
        cloud_info "\n--> Normalized installation order for all packages: #{all.collect(&:name).join(', ')}"
        all.each &block
      end
  end
end
