require 'net/ssh'
require 'net/scp'

module Pot
  module Transports
    class Ssh

      attr_reader :instance

      def initialize(instance) #:nodoc:
        @instance = instance
      end

      def execute(command)
        execute_on_connection!(command)
      end

      def transfer(source, destination, recursive = true)
        transfer_on_connection!(source, destination, recursive)
      end

      private

        def connection
          return @connection if defined?(@connection)
          options = { }
          # options[:verbose] = Logger::DEBUG if Pot.config.debug?
          # options[:verbose] = Logger::INFO
          options[:password] = instance.password if instance.password
          options[:port] = instance.port if instance.port
          @connection = Net::SSH.start(instance.host, instance.user, options)
          @connection
        end

        def transfer_on_connection!(source, destination, recursive)
          scp = Net::SCP.new(connection)
          scp.upload! source, destination, :recursive => recursive
        end

        def execute_on_connection!(command)
          exit_code = nil
          exit_signal = nil

          connection.open_channel do |channel|
            Pot.logger.debug("executing remote command: #{command}")
            channel.exec(command) do |ch, success|
              unless success
                abort "FAILED: couldn't execute command (connection.channel.exec)"
                Pot.logger.error("couldn't run remote command #{command}")
              end

              channel.on_data do |ch, data|
                Pot.logger.debug("stdout said-->\n#{data}\n")
              end

              channel.on_extended_data do |ch, type, data|
                next unless type == 1  # only handle stderr
                Pot.logger.debug("stderr said -->\n#{data}\n")
              end

              channel.on_request("exit-status") do |ch, data|
                exit_code = data.read_long
                if exit_code == 0
                  Pot.logger.debug('success')
                else
                  Pot.logger.debug('failed (%d).'%exit_code)
                end
              end

              channel.on_request("exit-signal") do |ch, data|
                exit_signal = data.read_long
                Pot.logger.debug("#{command} was signaled!: #{data.read_long}")
              end
            end
          end
          connection.loop
          exit_code
        end
    end
  end
end
